netapp_ontap.models.disk_path_info API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.disk_path_info`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class DiskPathInfoSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the DiskPathInfo object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `disk_path_name: str GET`

    Path-based disk name.

    Example: vsim4:3a.10

  `initiator: str GET`

    Initiator port.

    Example: 3a

  `node_name: str GET`

    Controller with the initiator port for this path.

    Example: vsim4

  `node_uuid: str GET`

    Controller UUID, to identify node for this path.

    Example: cf7fe057-526d-11ec-af4e-0050568e9df0

  `port_name: str GET`

    Name of the disk port.

    Example: A

  `port_type: str GET`

    Disk port type.

    Valid choices:

    - sas
    - fc
    - nvme
  `vmdisk_hypervisor_file_name: str GET`

    Virtual disk hypervisor file name.

    Example: xvds vol0a0567ae156ca59f6

  `wwnn: str GET`

    Target device's World Wide Node Name.

    Example: 5000c2971c1b2b8c

  `wwpn: str GET`

    Target device's World Wide Port Name.

    Example: 5000c2971c1b2b8d